# -*- coding: utf-8 -*-

"""A getter for HGNC."""

import logging

from bioversions.utils import Getter, VersionType, get_soup

__all__ = [
    "HGNCGetter",
]

logger = logging.getLogger(__name__)

PATH = "https://ftp.ebi.ac.uk/pub/databases/genenames/new/archive/monthly/json/"
PREFIX = "hgnc_complete_set_"
SUFFIX = ".json"


class HGNCGetter(Getter):
    """A getter for HGNC."""

    bioregistry_id = "hgnc"
    name = "HGNC"
    homepage_fmt = (
        "http://ftp.ebi.ac.uk/pub/databases/genenames/hgnc/"
        "archive/monthly/json/hgnc_complete_set_{version}.json"
    )

    version_type = VersionType.date

    def get(self) -> str:
        """Get the latest HGNC version number."""
        soup = get_soup(PATH)
        return max(
            anchor.attrs["href"][len(PREFIX) : -len(SUFFIX)]
            for anchor in soup.find_all("a")
            if anchor.attrs["href"].startswith(PREFIX)
        )


if __name__ == "__main__":
    HGNCGetter.print()



# -*- coding: utf-8 -*-

"""A getter for SGD."""

import requests

from bioversions.utils import Getter, VersionType

__all__ = [
    "SgdGetter",
]

VERSION_FILE = (
    "http://sgd-archive.yeastgenome.org/sequence/S288C_reference/dates_of_genome_releases.tab"
)


class SgdGetter(Getter):
    """A getter for SGD."""

    bioregistry_id = "sgd"
    name = "Saccharomyces Genome Database"
    date_fmt = "%Y-%m-%d"
    version_type = VersionType.date

    def get(self):
        """Get the latest SGD version number."""
        with requests.Session() as session:
            res = session.get(VERSION_FILE)
            d = {}
            lines = list(res.text.splitlines())
            # First 3 lines are headers
            lines = lines[3:]
            for line in lines:
                line = line.strip().split()
                # Some lines contain extra information
                d[line[0]] = line[1].replace("_", "-")
        version = max(d, key=d.get)
        return {
            "version": version,
            "date": d[version],
        }


if __name__ == "__main__":
    SgdGetter.print()



# -*- coding: utf-8 -*-

"""A getter for ITIS."""

from typing import Mapping

from bioversions.utils import Getter, VersionType, get_soup

__all__ = [
    "ITISGetter",
]

URL = "https://itis.gov/downloads/index.html"


class ITISGetter(Getter):
    """A getter for ITIS."""

    bioregistry_id = "itis"
    name = "ITIS"
    date_fmt = "%d-%B-%Y"
    version_type = VersionType.date

    def get(self) -> Mapping[str, str]:
        """Get the latest ITIS version number."""
        soup = get_soup(URL)
        cells = soup.find_all("td")
        for cell in cells:
            if "Database download files are currently from the " not in cell.text:
                continue
            bolds = list(cell.find_all("b"))
            return bolds[1].text
        raise ValueError


if __name__ == "__main__":
    ITISGetter.print()
